import sys
import os

file_path = os.path.abspath(__file__)
end = file_path.index('mns') + 16
project_path = file_path[0:end]
sys.path.append(project_path)
from mns_common.db.MongodbUtil import MongodbUtil
from mns_common.db.v2.MongodbUtilV2 import MongodbUtilV2
import mns_common.api.em.east_money_stock_api as east_money_stock_api
import pandas as pd
from loguru import logger
import mns_common.component.common_service_fun_api as common_service_fun_api
import mns_common.utils.data_frame_util as data_frame_util
import time
import mns_common.api.k_line.stock_minute_data_api as stock_minute_data_api
import mns_common.constant.db_name_constant as db_name_constant

mongodb_util_27017 = MongodbUtil('27017')
mongodb_util_27019 = MongodbUtil('27019')
mongodbUtilV2 = MongodbUtilV2('27017', 'extraIncome')


def create_index(db_util, db_name):
    index_create = [('symbol', 1), ('time', 1)]
    db_util.create_index(db_name, index_create)
    index_create_01 = [('time', 1)]
    db_util.create_index(db_name, index_create_01)
    index_create_02 = [('symbol', 1)]
    db_util.create_index(db_name, index_create_02)


def get_minute_data(symbol, freq, start_date, end_date):
    # 获取浦发银行60000.SH的历史分钟数据
    df = stock_minute_data_api.get_minute_data(symbol, start_date, end_date, freq,
                                               '')
    return df


# 287

def sync_all_stock(trade_date_list_df):
    de_list_stock_df = mongodb_util_27017.find_all_data('de_list_stock')
    de_list_stock_df = common_service_fun_api.classify_symbol(de_list_stock_df)
    de_list_stock_df = de_list_stock_df.loc[
        de_list_stock_df['classification'].isin(['K', 'C', 'S', 'H', 'X'])]
    # 对 classification 为 S 或 K 的数据，symbol 列加上 '.SH'，其他加上 '.SZ'

    de_list_stock_df['symbol'] = de_list_stock_df.apply(
        lambda row: row['symbol'] + '.SZ' if row['classification'] in ['S', 'C']
        else row['symbol'] + '.BJ' if row['classification'] in ['X']
        else row['symbol'] + '.SH',
        axis=1
    )

    real_time_quotes_all_stocks_df = east_money_stock_api.get_real_time_quotes_all_stocks()
    # 假设数字格式为 YYYYMMDD
    real_time_quotes_all_stocks_df['list_date'] = pd.to_datetime(real_time_quotes_all_stocks_df['list_date'],
                                                                 format='%Y%m%d')

    # 将日期格式化为字符串（YYYY-MM-DD）
    real_time_quotes_all_stocks_df['list_date'] = real_time_quotes_all_stocks_df['list_date'].dt.strftime('%Y-%m-%d')

    real_time_quotes_all_stocks_df = common_service_fun_api.classify_symbol(real_time_quotes_all_stocks_df)

    # 对 classification 为 S 或 K 的数据，symbol 列加上 '.SH'，其他加上 '.SZ'
    real_time_quotes_all_stocks_df['symbol'] = real_time_quotes_all_stocks_df.apply(
        lambda row: row['symbol'] + '.SZ' if row['classification'] in ['S', 'C']
        else row['symbol'] + '.BJ' if row['classification'] in ['X']
        else row['symbol'] + '.SH',
        axis=1
    )

    real_time_quotes_all_stocks_df = real_time_quotes_all_stocks_df.sort_values(by=['chg'], ascending=True)

    real_time_quotes_all_stocks_df['number'] = real_time_quotes_all_stocks_df['chg'].rank(method='first').astype(int)

    for stock_one in real_time_quotes_all_stocks_df.itertuples():
        classification = stock_one.classification
        if classification == 'X':
            db_name = db_name_constant.ONE_MINUTE_K_LINE_BFQ_BJ
        elif classification == 'S':
            db_name = db_name_constant.ONE_MINUTE_K_LINE_BFQ_S
        elif classification == 'H':
            db_name = 'one_minute_k_line_bfq_h'
        elif classification == 'K':
            db_name = 'one_minute_k_line_bfq_k'
        elif classification == 'C':
            db_name = 'one_minute_k_line_bfq_c'
        db_name = db_name + '_2025'
        create_index(mongodbUtilV2, db_name)
        trade_date_list_df_copy = trade_date_list_df.copy()

        list_date = stock_one.list_date
        trade_date_list_df_copy = trade_date_list_df_copy.loc[trade_date_list_df_copy['_id'] >= list_date]

        symbol = stock_one.symbol

        de_list_stock_df_one = de_list_stock_df.loc[de_list_stock_df['symbol'] == symbol]

        if data_frame_util.is_not_empty(de_list_stock_df_one):
            de_list_date = list(de_list_stock_df_one['de_list_date'])[0]
            trade_date_list_df_copy = trade_date_list_df_copy.loc[trade_date_list_df_copy['_id'] <= de_list_date]

        for i in range(0, len(trade_date_list_df_copy), 28):
            try:
                new_df = trade_date_list_df_copy.iloc[i:i + 28]
                first_df = new_df.iloc[0]  # 第一个 DataFrame
                last_df = new_df.iloc[-1]  # 最后一个 DataFrame
                begin_date = first_df.trade_date + ' 09:30:00'
                end_date = last_df.trade_date + ' 15:00:00'

                trade_date_list = list(new_df['trade_date'])
                if classification in ['K', 'H']:
                    symbol_quest = '1.' + symbol[0:6]
                else:
                    symbol_quest = '0.' + symbol[0:6]

                df = get_minute_data(symbol_quest, '1', begin_date, end_date)
                if data_frame_util.is_not_empty(df):
                    df['symbol'] = symbol
                    df = df[[
                        'symbol',
                        "time",
                        "open",
                        "close",
                        "high",
                        "low",
                        "amount",
                        "volume",
                    ]]
                    df['str_day'] = df['time'].str[:10]  #
                    df = df.loc[df['str_day'].isin(trade_date_list)]
                    if data_frame_util.is_not_empty(df):
                        df['time_tick'] = df['time'].str[11:19]
                        df = df.loc[df['time_tick'] <= '15:00:00']
                        del df['time_tick']
                        del df['str_day']
                        df['_id'] = df['symbol'] + '_' + df['time']
                        mongodbUtilV2.insert_mongo(df, db_name)
            except BaseException as e:
                time.sleep(2)
                first_df = new_df.iloc[0]  # 第一个 DataFrame
                last_df = new_df.iloc[-1]  # 最后一个 DataFrame
                begin_date = first_df.trade_date + ' 09:20:00'
                end_date = last_df.trade_date + ' 15:00:00'
                fail_dict = {'begin_date': begin_date,
                             'end_date': end_date,
                             'symbol': symbol,
                             'db_name': db_name
                             }
                fail_df = pd.DataFrame(fail_dict, index=[1])
                mongodbUtilV2.insert_mongo(fail_df, 'one_minute_k_line_bfq_fail_2025_03')

                logger.error("同步数据出现异常:{},{},{},{}", e, symbol, begin_date, end_date)
        logger.info("同步完数据:{},{}", stock_one.symbol, stock_one.name)


if __name__ == '__main__':
    # get_minute_data('833284.BJ', '1min', '2025-02-28 09:30:00', '2025-02-28 15:00:00')

    query_trade = {"$and": [{"trade_date": {"$gte": "2025-03-01"}}, {"trade_date": {"$lte": "2025-03-07"}}]}
    trade_date_list_df_all = mongodb_util_27017.find_query_data('trade_date_list', query_trade)

    sync_all_stock(trade_date_list_df_all)



import os
import sys

file_path = os.path.abspath(__file__)
end = file_path.index('mns') + 17
project_path = file_path[0:end]
sys.path.append(project_path)

from loguru import logger
import mns_common.api.em.east_money_stock_api as east_money_stock_api
from mns_common.db.MongodbUtil import MongodbUtil
import mns_common.utils.date_handle_util as date_handle_util
import mns_common.component.common_service_fun_api as common_service_fun_api
import mns_common.api.akshare.k_line_api as k_line_api
import mns_common.component.company.company_common_service_new_api as company_common_service_new_api

mongodb_util = MongodbUtil('27017')


def sync_bfq_k_line_data(period='daily',
                         hq='hfq',
                         hq_col='stock_hfq_daily',
                         end_date='22220101',
                         symbol=None):
    # 检查symbol是否以'6'开头
    if symbol.startswith('6'):
        symbol_a = '1.' + symbol
    else:
        symbol_a = '0.' + symbol
    stock_hfq_df = k_line_api.stock_zh_a_hist(symbol=symbol_a, period=period,
                                              start_date=date_handle_util.no_slash_date('1990-12-19'),
                                              end_date=date_handle_util.no_slash_date(end_date),
                                              adjust=hq)

    stock_hfq_df.rename(columns={"日期": "date", "开盘": "open",
                                 "收盘": "close", "最高": "high",
                                 "最低": "low", "成交量": "volume",
                                 "成交额": "amount", "振幅": "pct_chg",
                                 "涨跌幅": "chg", "涨跌额": "change",
                                 "换手率": "exchange"}, inplace=True)

    stock_hfq_df['symbol'] = symbol
    stock_hfq_df['_id'] = stock_hfq_df['symbol'] + '-' + stock_hfq_df['date']
    stock_hfq_df['last_price'] = round(((stock_hfq_df['close']) / (1 + stock_hfq_df['chg'] / 100)), 2)
    stock_hfq_df['max_chg'] = round(
        ((stock_hfq_df['high'] - stock_hfq_df['last_price']) / stock_hfq_df['last_price']) * 100, 2)
    stock_hfq_df['amount_level'] = round((stock_hfq_df['amount'] / common_service_fun_api.HUNDRED_MILLION), 2)
    stock_hfq_df['flow_mv'] = round(stock_hfq_df['amount'] * 100 / stock_hfq_df['exchange'], 2)
    stock_hfq_df['flow_mv_sp'] = round(stock_hfq_df['flow_mv'] / common_service_fun_api.HUNDRED_MILLION, 2)

    classification = common_service_fun_api.classify_symbol_one(symbol)
    stock_hfq_df['classification'] = classification
    stock_hfq_df = stock_hfq_df.sort_values(by=['date'], ascending=False)
    insert_data(stock_hfq_df, hq_col, symbol)
    logger.info(period + 'k线同步-' + hq + '-' + symbol)
    return stock_hfq_df


def sync_all_bfq_k_line(period='daily',
                        hq='hfq',
                        hq_col='stock_hfq_daily',
                        end_date='22220101',
                        symbol=None):
    real_time_quotes_now_es = east_money_stock_api.get_real_time_quotes_all_stocks()

    symbol_list = list(real_time_quotes_now_es['symbol'])
    # 退市公司
    de_list_company = company_common_service_new_api.get_de_list_company()
    symbol_list.extend(de_list_company)
    symbol_list = set(symbol_list)
    if symbol is not None:
        symbol_list = [symbol]
    for symbol in symbol_list:
        try:
            sync_bfq_k_line_data(period,
                                 hq,
                                 hq_col,
                                 end_date,
                                 symbol)
        except BaseException as e:
            logger.warning("同步不复权k线:{},{}", symbol, e)


def insert_data(stock_hfq_df, hq_col, symbol):
    query = {'symbol': symbol}
    tag = mongodb_util.remove_data(query, hq_col)
    success = tag.acknowledged
    if success:
        mongodb_util.insert_mongo(stock_hfq_df, hq_col)


if __name__ == '__main__':
    sync_all_bfq_k_line('daily',
                        '',
                        'stock_bfq_daily',
                        None,
                        None)



import sys
import os

file_path = os.path.abspath(__file__)
end = file_path.index('mns') + 16
project_path = file_path[0:end]
sys.path.append(project_path)
from loguru import logger


def db_export(db, col):
    cmd = 'F:/mongo/bin/mongodump.exe --host ' + db + ' -d patience -c ' + col + ' -o D:/back'
    os.system(cmd)
    logger.info("export finished:{}", col)


def db_import(db, col):
    cmd = 'F:/mongo/bin/mongorestore.exe --host ' + db + ' -d patience -c ' + col + ' D:/back/patience/' + col + '.bson'
    os.system(cmd)

    path = 'D:\\back\\patience\\' + col + '.bson'
    cmd_del = 'del /F /S /Q ' + path
    os.system(cmd_del)

    logger.info("import finished:{}", col)


def handle_one_col(col_name):
    db_export('127.0.0.1:27017', col_name)
    db_import('127.0.0.1:27019', col_name)


if __name__ == '__main__':
    handle_one_col('one_minute_k_line_bfq_h')



import sys
import os

file_path = os.path.abspath(__file__)
end = file_path.index('mns') + 16
project_path = file_path[0:end]
sys.path.append(project_path)
import mns_common.utils.cmd_util as cmd_util
import time
import mns_scheduler.trade.auto_login.trader_auto_service as trader_auto_service
import mns_common.utils.data_frame_util as data_frame_util
from loguru import logger

# 交易任务
TRADER_SERVER_PATH = 'H:\\mns-trader.bat'
# 实时行情同步任务 python名称
TRADER_SERVER_NAME = "mns_trader"


# 打开交易客户端
def open_trader_terminal():
    # 打开任务进程
    cmd_util.open_bat_file(TRADER_SERVER_PATH)
    # 自动登陆
    trader_auto_service.auto_login()
    time.sleep(5)
    # 需先打开同花顺终端在开始交易服务
    kill_server()
    time.sleep(5)
    # 打开任务进程
    cmd_util.open_bat_file(TRADER_SERVER_PATH)


def kill_server():
    all_cmd_processes = cmd_util.get_all_process()
    all_cmd_processes_trader = all_cmd_processes.loc[
        (all_cmd_processes['total_info'].str.contains(TRADER_SERVER_NAME, case=False, na=False))]
    if data_frame_util.is_not_empty(all_cmd_processes_trader):
        for processes_one in all_cmd_processes_trader.itertuples():
            try:
                process_pid = processes_one.process_pid
                cmd_util.kill_process_by_pid(process_pid)
            except BaseException as e:
                logger.error("杀死进程异常:{}", e)


if __name__ == '__main__':
    open_trader_terminal()



import sys
import os

file_path = os.path.abspath(__file__)
end = file_path.index('mns') + 16
project_path = file_path[0:end]
sys.path.append(project_path)
import mns_scheduler.industry.ths.ths_industry_index_service as ths_industry_index_service
from mns_common.db.MongodbUtil import MongodbUtil
import time
from datetime import datetime
from loguru import logger
import mns_common.utils.data_frame_util as data_frame_util
import mns_common.api.ths.concept.app.ths_concept_detail_app as ths_concept_detail_app

mongodb_util = MongodbUtil('27017')
import mns_common.constant.db_name_constant as db_name_constant


# 同步同花顺行业指数
def sync_ths_industry_index():
    ths_industry_index_df = ths_industry_index_service.get_ths_index_by_api(1)
    if data_frame_util.is_empty(ths_industry_index_df):
        return None
    ths_industry_index_df['_id'] = ths_industry_index_df['block_code']
    ths_industry_index_df = ths_industry_index_df[[
        '_id',
        'turnover',
        'block_market',
        'block_code',
        'block_name',
        'net_inflow_of_main_force',
        'chg'
    ]]
    now_date = datetime.now()
    str_now_date = now_date.strftime('%Y-%m-%d %H:%M:%S')
    ths_industry_index_df['str_now_date'] = str_now_date
    mongodb_util.save_mongo(ths_industry_index_df, db_name_constant.THS_INDUSTRY_LIST)


def sync_ths_industry_detail():
    ths_industry_list_df = mongodb_util.find_all_data(db_name_constant.THS_INDUSTRY_LIST)
    for industry_one in ths_industry_list_df.itertuples():
        try:
            time.sleep(1)
            now_date = datetime.now()
            str_now_date = now_date.strftime('%Y-%m-%d %H:%M:%S')

            ths_industry_symbol_detail_df = ths_concept_detail_app.get_ths_concept_detail_by_app(
                industry_one.block_code)
            ths_industry_symbol_detail_df = ths_industry_symbol_detail_df.rename(
                columns={"concept_code": 'ths_industry_code',
                         "concept_name": 'ths_industry_name',
                         })
            if data_frame_util.is_empty(ths_industry_symbol_detail_df):
                continue
            ths_industry_symbol_detail_df['str_now_date'] = str_now_date
            ths_industry_symbol_detail_df['_id'] = ths_industry_symbol_detail_df['symbol']
            mongodb_util.save_mongo(ths_industry_symbol_detail_df, db_name_constant.THS_STOCK_INDUSTRY_DETAIL)
            logger.info("同步ths行业股票详情:{}", industry_one.block_name)

        except BaseException as e:
            logger.error("同步ths行业股票详情异常:{}", e)


if __name__ == '__main__':
    sync_ths_industry_index()
    sync_ths_industry_detail()



import sys
import os

file_path = os.path.abspath(__file__)
end = file_path.index('mns') + 16
project_path = file_path[0:end]
sys.path.append(project_path)
from mns_common.db.MongodbUtil import MongodbUtil
from loguru import logger
import mns_common.utils.date_handle_util as date_handle_util
mongodb_util = MongodbUtil('27017')

from mns_scheduler.db.script.sync.remote_mongo_util import RemoteMongodbUtil


remote_mongodb_util = RemoteMongodbUtil('27017')


def fix_error_deal_days(db_name):
    realtime_quotes_now_zt_new_kc_open_df = mongodb_util.find_query_data(db_name, {})
    realtime_quotes_now_zt_new_kc_open_df['id_key'] = realtime_quotes_now_zt_new_kc_open_df['_id']
    for stock_one in realtime_quotes_now_zt_new_kc_open_df.itertuples():
        try:
            symbol = stock_one.symbol
            str_day = stock_one.str_day
            query = {'symbol': symbol, 'date': {"$lt": date_handle_util.no_slash_date(str_day)}}
            deal_days = mongodb_util.count(query, 'stock_qfq_daily')
            new_values = {"$set": {"deal_days": deal_days}}
            id_key = stock_one.id_key
            update_query = {'_id': id_key}
            mongodb_util.update_many(update_query, new_values, db_name)
            logger.info("更新到:{},{}", symbol, str_day)
        except BaseException as e:
            logger.error("出现异常:{},{},{}", symbol, str_day, e)


if __name__ == '__main__':
    # db_name_0 = 'realtime_quotes_now_zt_new_kc_open'
    db_name_01 = 'stock_high_chg_pool'
    # fix_error_deal_days(db_name_0)
    fix_error_deal_days(db_name_01)



import sys
import os

file_path = os.path.abspath(__file__)
end = file_path.index('mns') + 16
project_path = file_path[0:end]
sys.path.append(project_path)

import pandas as pd
import mns_common.utils.date_handle_util as date_handle_util
import mns_common.constant.db_name_constant as db_name_constant
from mns_common.db.MongodbUtil import MongodbUtil
import mns_common.component.company.company_common_service_api as company_common_service_api

mongodb_util = MongodbUtil('27017')
# 高涨幅阈值
HIGH_CHG = 50


# 最近大涨股票
def calculate_recent_hot_stocks(stock_qfq_daily_60, symbol, str_day):
    company_df = company_common_service_api.get_company_info_industry_list_date()
    company_one_df = company_df.loc[company_df['_id'] == symbol]
    company_one_df['list_date_01'] = pd.to_datetime(company_one_df['list_date'], format='%Y%m%d')
    list_date = list(company_one_df['list_date_01'])[0]

    str_list_date = date_handle_util.no_slash_date(list_date.strftime('%Y-%m-%d'))
    # 排除上市第一天的数据
    stock_qfq_daily_60 = stock_qfq_daily_60.loc[stock_qfq_daily_60['date'] > str_list_date]

    stock_qfq_daily_05 = stock_qfq_daily_60.iloc[0:5]

    stock_qfq_daily_10 = stock_qfq_daily_60.iloc[0:10]

    stock_qfq_daily_20 = stock_qfq_daily_60.iloc[0:20]

    stock_qfq_daily_30 = stock_qfq_daily_60.iloc[0:30]
    sum_five_chg = round(sum(stock_qfq_daily_05['chg']), 2)
    sum_ten_chg = round(sum(stock_qfq_daily_10['chg']), 2)

    sum_twenty_chg = round(sum(stock_qfq_daily_20['chg']), 2)

    sum_thirty_chg = round(sum(stock_qfq_daily_30['chg']), 2)

    sum_sixty_chg = round(sum(stock_qfq_daily_60['chg']), 2)
    if (sum_sixty_chg >= HIGH_CHG
            or sum_ten_chg >= HIGH_CHG
            or sum_twenty_chg >= HIGH_CHG
            or sum_thirty_chg >= HIGH_CHG
            or sum_sixty_chg >= HIGH_CHG):
        query = {'symbol': symbol}
        company_info_df = mongodb_util.find_query_data(db_name_constant.COMPANY_INFO, query)
        name = list(company_info_df['name'])[0]
        hot_stocks_dict = {
            "_id": str_day + "_" + symbol,
            "symbol": symbol,
            "name": name,
            "str_day": str_day,
            "sum_five_chg": sum_five_chg,
            "sum_ten_chg": sum_ten_chg,
            "sum_twenty_chg": sum_twenty_chg,
            "sum_thirty_chg": sum_thirty_chg,
            "sum_sixty_chg": sum_sixty_chg,
        }
        hot_stocks_df = pd.DataFrame(hot_stocks_dict, index=[1])
        mongodb_util.save_mongo(hot_stocks_df, db_name_constant.RECENT_HOT_STOCKS)



import sys
import os

file_path = os.path.abspath(__file__)
end = file_path.index('mns') + 16
project_path = file_path[0:end]
sys.path.append(project_path)
import mns_common.component.deal.deal_service_api as deal_service_api
from mns_common.component.deal.terminal_enum import TerminalEnum
import time


# qmt 自动登录
def qmt_auto_login():
    deal_service_api.auto_login(TerminalEnum.QMT.terminal_code)


# 同花顺自动登陆
def ths_auto_login():
    deal_service_api.auto_login(TerminalEnum.EASY_TRADER.terminal_code)


def auto_login():
    qmt_auto_login()
    time.sleep(5)
    ths_auto_login()


if __name__ == '__main__':
    auto_login()



import sys
import os

file_path = os.path.abspath(__file__)
end = file_path.index('mns') + 16
project_path = file_path[0:end]
sys.path.append(project_path)
import mns_scheduler.zt.open_data.kcx_high_chg_open_data_sync as kcx_high_chg_open_data_sync
from loguru import logger

from mns_common.db.MongodbUtil import MongodbUtil
import mns_common.utils.data_frame_util as data_frame_util

mongodb_util = MongodbUtil('27017')
mongodb_util_21019 = MongodbUtil('27019')
realtime_quotes_now_zt_new_kc_open_field = ['_id',
                                            'symbol',
                                            'name',
                                            'chg',
                                            'quantity_ratio',
                                            'amount_level',
                                            'real_exchange',
                                            'sum_main_inflow_disk',
                                            'disk_diff_amount',
                                            'flow_mv_level',
                                            'total_mv_level',
                                            'today_chg',
                                            'industry',
                                            'first_sw_industry',
                                            'second_sw_industry',
                                            'third_sw_industry',
                                            'ths_concept_name',
                                            'ths_concept_code',
                                            'em_industry',
                                            'disk_ratio',
                                            'company_type',
                                            'reference_main_inflow',
                                            'main_inflow_multiple', 'super_main_inflow_multiple',
                                            'disk_diff_amount_exchange', 'exchange', 'amount', 'today_main_net_inflow',
                                            'today_main_net_inflow_ratio', 'super_large_order_net_inflow',
                                            'super_large_order_net_inflow_ratio', 'large_order_net_inflow',
                                            'large_order_net_inflow_ratio', 'now_price',
                                            'high', 'low', 'open', 'yesterday_price',
                                            'volume', 'total_mv', 'flow_mv',
                                            'outer_disk', 'inner_disk',
                                            'classification', 'str_now_date', 'number', 'str_day',
                                            'yesterday_high_chg',
                                            'ths_concept_sync_day', 'mv_circulation_ratio',
                                            'large_inflow_multiple', 'real_main_inflow_multiple',
                                            'max_real_main_inflow_multiple', 'list_date',
                                            'real_super_main_inflow_multiple', 'real_flow_mv',
                                            'real_disk_diff_amount_exchange', 'no_open_data']


#     query = {'$and': [{"_id": {'$lte': str_end}}, {"_id": {'$gte': '2022-04-25'}}]}
def sync_all_high_chg_data(str_end):
    query = {'$and': [{"_id": {'$lte': str_end}}, {"_id": {'$gte': '2024-03-01'}}]}
    trade_date_list = mongodb_util.find_query_data('trade_date_list', query)
    trade_date_list = trade_date_list.sort_values(by=['trade_date'], ascending=False)
    for date_one in trade_date_list.itertuples():
        try:
            str_day = date_one.trade_date
            kcx_high_chg_open_data_sync.sync_all_kc_zt_data(str_day, None)
        except BaseException as e:
            logger.error("发生异常:{},{}", str_day, e)


def fix_miss_data(str_end):
    query = {'$and': [{"_id": {'$lte': str_end}}, {"_id": {'$gte': '2023-12-05'}}]}
    trade_date_list = mongodb_util.find_query_data('trade_date_list', query)
    trade_date_list = trade_date_list.sort_values(by=['trade_date'], ascending=False)
    for date_one in trade_date_list.itertuples():
        try:
            str_day = date_one.trade_date
            query = {"str_day": str_day, "miss_out": True}
            stock_high_chg_pool_df = mongodb_util.find_query_data('stock_high_chg_pool', query)
            if data_frame_util.is_empty(stock_high_chg_pool_df):
                continue
            miss_symbol_list = list(stock_high_chg_pool_df['symbol'])
            kcx_high_chg_open_data_sync.sync_all_kc_zt_data(str_day, miss_symbol_list)
        except BaseException as e:
            logger.error("发生异常:{},{}", str_day, e)


if __name__ == '__main__':
    kcx_high_chg_open_data_sync.sync_all_kc_zt_data('2025-02-21', None)
    # sync_all_kc_zt_data('2023-08-16')
    # sync_all_kc_zt_data('2023-07-07')
    # realtime_quotes_now_zt_new_kc_open_sync()
    # hui_ce_all('2023-06-16')
    # fix_diff_day()
    # sync_all_kc_zt_data('2023-06-30')

    # sync_all_kc_zt_data('2023-07-05')
    # sync_one_day_open_data('2023-07-05')
    # sync_all_kc_zt_data('2023-06-30')
    # sync_one_day_open_data('2023-05-31')
    # hui_ce_all('2023-03-16')
    # sync_all_kc_zt_data('2023-06-28')
    # sync_all_kc_zt_data('2023-05-12')
    # sync_all_kc_zt_data('2023-05-15')
    # sync_all_kc_zt_data('2023-05-16')
    # sync_all_kc_zt_data('2023-05-17')
    # sync_all_kc_zt_data('2023-05-10')



import sys
import os

file_path = os.path.abspath(__file__)
end = file_path.index('mns') + 16
project_path = file_path[0:end]
sys.path.append(project_path)
import akshare as ak


def sync_us_company_info():
    stock_us_spot_em_df = ak.stock_us_spot_em()
    stock_us_spot_em_df = stock_us_spot_em_df.rename(columns={
        "序号": "index",
        "代码": "symbol",
        "名称": "name",
        "涨跌额": "change_price",
        "涨跌幅": "chg",
        "开盘价": "open",
        "最高价": "high",
        "最低价": "low",
        "最新价": "now_price",
        "昨收价": "last_price",
        "总市值": "total_mv",
        "市盈率": "pe",
        "成交量": "volume",
        "成交额": "amount",
        "振幅": "pct_chg",
        "换手率": "exchange"
    })
    stock_us_spot_em_df = stock_us_spot_em_df.sort_values(by=['amount'], ascending=False)
    stock_us_spot_em_df = stock_us_spot_em_df.fillna(0)
    stock_us_spot_em_df = stock_us_spot_em_df.loc[stock_us_spot_em_df['total_mv']!=0]
    stock_us_spot_em_df.to_csv('us_stock.csv', index=False)
    return stock_us_spot_em_df


if __name__ == '__main__':
    sync_us_company_info()



import akshare as ak
import pandas as pd
from mns_common.db.MongodbUtil import MongodbUtil

mongodb_util = MongodbUtil('27017')


def us_stock():
    # 输入参数
    symbol = input("请输入股票代码（all:全量(时间很长),特定代码:106.TTE）：")
    start_date = input("请输入开始日期（格式：YYYYMMDD）：")
    end_date = input("请输入结束日期（格式：YYYYMMDD）：")
    fq = input("请输入复权信息（前复权:qfq,不复权:bfq,后复权:hfq）：")
    k_line_period = input("请输入k线周期（日线:daily,周线:weekly,月线:monthly）：")
    db_name = "us_stock_" + fq + "_" + k_line_period
    if fq == 'bfq':
        fq = ''
    if symbol != 'all':
        # 获取股票历史数据
        stock_us_hist_df = ak.stock_us_hist(symbol=symbol,
                                            period=k_line_period,
                                            start_date=start_date,
                                            end_date=end_date,
                                            adjust=fq)
        # 保存数据到 CSV 文件
        stock_us_hist_df.to_csv(f"{symbol}_historical_data.csv", index=False)
        print(f"数据已保存到 {symbol}_historical_data.csv")
    else:
        stock_us_spot_em_df = ak.stock_us_spot_em()
        stock_us_spot_em_df = stock_us_spot_em_df.rename(columns={
            "序号": "index",
            "代码": "symbol",
            "名称": "name",
            "涨跌额": "change_price",
            "涨跌幅": "chg",
            "开盘价": "open",
            "最高价": "high",
            "最低价": "low",
            "最新价": "now_price",
            "昨收价": "last_price",
            "总市值": "total_mv",
            "市盈率": "pe",
            "成交量": "volume",
            "成交额": "amount",
            "振幅": "pct_chg",
            "换手率": "exchange"
        })
        stock_us_spot_em_df = stock_us_spot_em_df.sort_values(by=['amount'], ascending=False)
        stock_us_spot_em_df = stock_us_spot_em_df.fillna(0)
        stock_us_spot_em_df = stock_us_spot_em_df.loc[stock_us_spot_em_df['total_mv'] != 0]

        k_line_result = pd.DataFrame()

        for stock_us_one in stock_us_spot_em_df.itertuples():
            try:
                # 获取股票历史数据
                stock_us_hist_df = ak.stock_us_hist(symbol=stock_us_one.symbol,
                                                    period=k_line_period,
                                                    start_date=start_date,
                                                    end_date=end_date,
                                                    adjust=fq)
                stock_us_hist_df = stock_us_hist_df.rename(columns={
                    "日期": "date",
                    "涨跌额": "change_price",
                    "涨跌幅": "chg",
                    "开盘": "open",
                    "最高": "high",
                    "最低": "low",
                    "收盘": "close",
                    "成交量": "volume",
                    "成交额": "amount",
                    "振幅": "pct_chg",
                    "换手率": "exchange"
                })

                k_line_result = pd.concat([stock_us_hist_df, k_line_result])
                stock_us_hist_df['_id'] = stock_us_one.symbol + '_' + stock_us_hist_df['date']
                stock_us_hist_df['symbol'] = stock_us_one.symbol
                stock_us_hist_df['name'] = stock_us_one.name
                mongodb_util.insert_mongo(stock_us_hist_df, db_name)
                print(f"同步k线数据到: {stock_us_one.name}")
            except BaseException as e:
                print(f"同步数据发生异常: {stock_us_one.name}, {e}")

        # 保存数据到 CSV 文件
        k_line_result.to_csv(f"{symbol}_historical_data.csv", index=False)
        print(f"数据已保存到 {symbol}_historical_data.csv")


if __name__ == "__main__":
    us_stock()



import sys
import os

file_path = os.path.abspath(__file__)
end = file_path.index('mns') + 16
project_path = file_path[0:end]
sys.path.append(project_path)
import mns_common.api.em.east_money_debt_api as east_money_debt_api
from datetime import datetime
import mns_common.constant.db_name_constant as db_name_constant
from mns_common.db.MongodbUtil import MongodbUtil

mongodb_util = MongodbUtil('27017')


# 同步可转债信息
def sync_debt_info():
    now_date = datetime.now()
    str_now_day = now_date.strftime('%Y-%m-%d')
    kzz_bond_info_df = east_money_debt_api.get_kzz_bond_info()
    kzz_bond_info_df = kzz_bond_info_df.fillna(0)
    kzz_bond_info_df['apply_date'] = kzz_bond_info_df['apply_date'].astype(str)
    kzz_bond_info_df['winning_date'] = kzz_bond_info_df['winning_date'].astype(str)
    kzz_bond_info_df['list_date'] = kzz_bond_info_df['list_date'].astype(str)
    kzz_bond_info_df['due_date'] = kzz_bond_info_df['due_date'].astype(str)
    kzz_bond_info_df = kzz_bond_info_df.loc[kzz_bond_info_df['due_date'] >= str_now_day]
    mongodb_util.remove_all_data(db_name_constant.KZZ_DEBT_INFO)
    kzz_bond_info_df['_id'] = kzz_bond_info_df['symbol']
    mongodb_util.insert_mongo(kzz_bond_info_df, db_name_constant.KZZ_DEBT_INFO)


if __name__ == '__main__':
    sync_debt_info()



import sys
import os

file_path = os.path.abspath(__file__)
end = file_path.index('mns') + 16
project_path = file_path[0:end]
sys.path.append(project_path)
from mns_common.db.MongodbUtil import MongodbUtil
import mns_common.utils.date_handle_util as date_handle_util
from mns_common.component.classify.symbol_classify_param import stock_type_classify_param
import mns_common.utils.data_frame_util as data_frame_util

# import functools

mongodb_util = MongodbUtil('27017')


# 处理月线 周线 todo 暂时简单计算周线之和
def handle_month_week_line(k_line_info, str_day, symbol, deal_days):
    sub_stock_new_max_deal_days = stock_type_classify_param['sub_new_stock_max_deal_days']
    if deal_days > sub_stock_new_max_deal_days:
        k_line_info['last_year_chg'] = 0
        k_line_info['now_year_chg'] = 0
        k_line_info = handle_month_line(k_line_info, str_day, symbol)
        k_line_info = handle_week_line(k_line_info, str_day, symbol)

    else:
        k_line_info['week01'] = 0
        k_line_info['week02'] = 0
        k_line_info['week03'] = 0
        k_line_info['week04'] = 0
        k_line_info['sum_week'] = 0
        k_line_info['week_num'] = 0
        k_line_info['week_last_day'] = '19890729'

        k_line_info['sum_month'] = 0
        k_line_info['month_num'] = 0
        k_line_info['month01'] = 0
        k_line_info['month02'] = 0
        k_line_info['month01_date'] = '19890729'
        k_line_info['month02_date'] = '19890729'

        k_line_info['last_year_chg'] = 0
        k_line_info['now_year_chg'] = 0

    return k_line_info


# 处理月线
def handle_month_line(k_line_info, str_day, symbol):
    now_year = int(str_day[0:4])
    last_year = str(now_year - 1)

    now_month_begin_day = str_day[0:7] + '-01'

    last_year_begin_day = last_year + '-01-01'
    now_year_begin_day = str(now_year) + '-01-01'

    query = {"symbol": symbol,
             'date': {"$gte": date_handle_util.no_slash_date(last_year_begin_day)}}
    stock_hfq_monthly_all = mongodb_util.find_query_data('stock_qfq_monthly', query)
    if data_frame_util.is_empty(stock_hfq_monthly_all):
        k_line_info['sum_month'] = 0

    else:
        stock_hfq_monthly_all = stock_hfq_monthly_all.sort_values(by=['date'], ascending=False)
        stock_hfq_monthly_all = stock_hfq_monthly_all.loc[
            stock_hfq_monthly_all['date'] <= date_handle_util.no_slash_date(now_month_begin_day)]

        stock_hfq_monthly_last_year = stock_hfq_monthly_all.loc[
            stock_hfq_monthly_all['date'] < date_handle_util.no_slash_date(now_year_begin_day)]

        stock_hfq_monthly_now_year = stock_hfq_monthly_all.loc[
            stock_hfq_monthly_all['date'] > date_handle_util.no_slash_date(now_year_begin_day)]

        # 最近两个月k线
        before_two_month_stock_hfq_monthly = stock_hfq_monthly_all.iloc[0:2]
        month_num = before_two_month_stock_hfq_monthly.shape[0]
        k_line_info['month_num'] = month_num

        if month_num == 0:
            k_line_info['sum_month'] = 0
            k_line_info['month01'] = 0
            k_line_info['month02'] = 0
            k_line_info['month01_date'] = '19890729'
            k_line_info['month02_date'] = '19890729'
        elif month_num == 1:
            k_line_info['month01'] = before_two_month_stock_hfq_monthly.iloc[0].chg
            k_line_info['month02'] = 0
            k_line_info['month01_date'] = before_two_month_stock_hfq_monthly.iloc[0].date
            k_line_info['month02_date'] = '19890729'
            k_line_info['sum_month'] = before_two_month_stock_hfq_monthly.iloc[0].chg
        elif month_num == 2:
            k_line_info['month01'] = before_two_month_stock_hfq_monthly.iloc[0].chg
            k_line_info['month02'] = before_two_month_stock_hfq_monthly.iloc[1].chg
            k_line_info['month01_date'] = before_two_month_stock_hfq_monthly.iloc[0].date
            k_line_info['month02_date'] = before_two_month_stock_hfq_monthly.iloc[1].date
            close_price = before_two_month_stock_hfq_monthly.iloc[0].close
            open_price = before_two_month_stock_hfq_monthly.iloc[1].last_price
            sum_chg = round((close_price - open_price) * 100 / open_price, 2)
            k_line_info['sum_month'] = sum_chg

        last_year_month_number = stock_hfq_monthly_last_year.shape[0]
        if last_year_month_number == 0:
            k_line_info['last_year_chg'] = 0
        elif last_year_month_number == 1:
            k_line_info['last_year_chg'] = stock_hfq_monthly_last_year.iloc[0].chg
        else:
            # chg_list = list(stock_hfq_monthly_last_year['chg'])
            # # 将列表中的每个元素加上1
            # updated_list = [round((x / 100) + 1, 2) for x in chg_list]
            #
            # # 使用 functools.reduce 将列表中的所有元素相乘
            # last_year_chg = functools.reduce(lambda x, y: x * y, updated_list)
            close_price = stock_hfq_monthly_last_year.iloc[0].close
            open_price = stock_hfq_monthly_last_year.iloc[last_year_month_number - 1].last_price
            last_year_chg = round((close_price - open_price) * 100 / open_price, 2)
            k_line_info['last_year_chg'] = last_year_chg

        now_year_month_number = stock_hfq_monthly_now_year.shape[0]
        if now_year_month_number == 0:
            k_line_info['now_year_chg'] = 0
        elif now_year_month_number == 1:
            k_line_info['now_year_chg'] = stock_hfq_monthly_now_year.iloc[0].chg
        else:
            close_price = stock_hfq_monthly_now_year.iloc[0].close
            open_price = stock_hfq_monthly_now_year.iloc[now_year_month_number - 1].last_price
            last_year_chg = round((close_price - open_price) * 100 / open_price, 2)
            k_line_info['now_year_chg'] = last_year_chg

    return k_line_info


# 处理周线
def handle_week_line(k_line_info, str_day, symbol):
    month_begin_day = str_day[0:7] + '-01'
    query = {"symbol": symbol,
             '$and': [{'date': {"$gte": date_handle_util.no_slash_date(month_begin_day)}},
                      {'date': {"$lt": date_handle_util.no_slash_date(str_day)}}]}
    stock_hfq_weekly = mongodb_util.find_query_data('stock_qfq_weekly', query)
    week_num = stock_hfq_weekly.shape[0]
    if week_num > 0:
        stock_hfq_weekly = stock_hfq_weekly.sort_values(by=['date'], ascending=False)
        k_line_info['sum_week'] = round(sum(stock_hfq_weekly['chg']), 2)
    else:
        k_line_info['sum_week'] = 0
    k_line_info['week_num'] = week_num
    if week_num == 1:
        k_line_info['week01'] = stock_hfq_weekly.iloc[0].chg
        k_line_info['week02'] = 0
        k_line_info['week03'] = 0
        k_line_info['week04'] = 0
    elif week_num == 2:
        k_line_info['week01'] = stock_hfq_weekly.iloc[0].chg
        k_line_info['week02'] = stock_hfq_weekly.iloc[1].chg
        k_line_info['week03'] = 0
        k_line_info['week04'] = 0
    elif week_num == 3:
        k_line_info['week01'] = stock_hfq_weekly.iloc[0].chg
        k_line_info['week02'] = stock_hfq_weekly.iloc[1].chg
        k_line_info['week03'] = stock_hfq_weekly.iloc[2].chg
        k_line_info['week04'] = 0
    elif week_num >= 4:
        k_line_info['week01'] = stock_hfq_weekly.iloc[0].chg
        k_line_info['week02'] = stock_hfq_weekly.iloc[1].chg
        k_line_info['week03'] = stock_hfq_weekly.iloc[2].chg
        k_line_info['week04'] = stock_hfq_weekly.iloc[3].chg
    elif week_num == 0:
        k_line_info['week01'] = 0
        k_line_info['week02'] = 0
        k_line_info['week03'] = 0
        k_line_info['week04'] = 0
        k_line_info['week_last_day'] = month_begin_day
        k_line_info['sum_week'] = 0
        return k_line_info
    stock_hfq_weekly = stock_hfq_weekly.sort_values(by=['date'], ascending=False)
    stock_hfq_weekly_last = stock_hfq_weekly.iloc[0:1]
    k_line_info['week_last_day'] = list(stock_hfq_weekly_last['date'])[0]

    return k_line_info



import sys
import os

file_path = os.path.abspath(__file__)
end = file_path.index('mns') + 16
project_path = file_path[0:end]
sys.path.append(project_path)

import mns_common.utils.data_frame_util as data_frame_util
from mns_scheduler.db.script.sync.remote_mongo_util import RemoteMongodbUtil
from mns_scheduler.db.script.sync.local_mongo_util import LocalMongodbUtil
from loguru import logger
import numpy as np

remote_mongodb_util = RemoteMongodbUtil('27017')
local_mongodb_util = LocalMongodbUtil('27017')


def sync_real_time_data(str_day, min_number, max_number):
    db_name = 'realtime_quotes_now_' + str_day
    while min_number <= max_number:
        query = {'number': min_number}
        data_df = remote_mongodb_util.find_query_data(db_name, query)
        local_mongodb_util.insert_mongo(data_df, db_name)
        min_number = min_number + 1
        logger.info(min_number)


def sync_k_line(str_day):
    query = {"str_day": str_day}
    db_name = 'k_line_info'
    data_df = remote_mongodb_util.find_query_data(db_name, query)
    try:
        local_mongodb_util.save_mongo(data_df, db_name)
    except BaseException as e:
        pass


if __name__ == '__main__':

    str_day_01 = '2025-02-18'
    sync_k_line(str_day_01)
    # sync_k_line(str_day_01)
    # sync_k_line('2024-11-13')
    # sync_k_line('2024-11-12')
    # sync_k_line('2024-11-15') 232
    sync_real_time_data(str_day_01, 1, 2000)
    # sync_real_time_data('2024-11-15', 10, 1010)

    sync_k_line('2024-12-20')
    sync_k_line('2024-12-19')
    sync_k_line('2024-12-18')
    sync_k_line('2024-12-17')
    sync_k_line('2024-12-16')

    sync_k_line('2024-12-13')
    sync_k_line('2024-12-12')
    sync_k_line('2024-12-11')
    sync_k_line('2024-12-10')
    sync_k_line('2024-12-09')

    sync_k_line('2024-12-06')
    sync_k_line('2024-12-05')
    sync_k_line('2024-12-04')
    sync_k_line('2024-12-03')
    sync_k_line('2024-12-02')

    # sync_real_time_data('2024-12-20', 1000, 2000)
    # sync_real_time_data('2024-11-13', 10, 1010)
